=========
ChangeLog
=========


v0.1.4
======

* Added option "keep_items"
* Added option "force_list"
* Corrected parameters passed to `map_return`
* Enabled option "comparers" to accept a single string
* Small performance enhancements (moved to generators & tuples where
  appropriate)


v0.1.3
======

* Added support for post-processing the selected objects via the
  `map_item`, `map_list`, and `map_return` options


v0.1.2
======

* Added fix for non-function closure cells


v0.1.1
======

* First public release
